enum Delegee {
Bound(Trait),
Impls(Trait, Impl),
}Expand description
A field that we want to delegate can offer the enclosing struct trait to implement in two ways. The first way is when the field actually implements the trait and the second way is when the field has a bound type parameter. We handle these cases in different ways hence the enum.
Variants
Implementations